package	jp.co.sds_corp.jdbrowser.connect;

import java.sql.Driver;
import java.util.Iterator;
import java.util.Properties;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.db.DbInfo;

/**
* DB接続情報を保持します。
<pre>
&lt;db name="oracle"&gt;
	&lt;jar&gt;../jdbc/ojdbc14.jar&lt;/jar&gt;
	&lt;driver&gt;oracle.jdbc.driver.OracleDriver&lt;/driver&gt;
	&lt;url&gt;jdbc:oracle:thin:@192.168.0.1:1521:SID&lt;/url&gt;
	&lt;user&gt;user&lt;/user&gt;
	&lt;password&gt;password&lt;/password&gt;
	&lt;catalog&gt;CATALOG&lt;/catalog&gt;
	&lt;schema&gt;SCHEMA&lt;/schema&gt;
	&lt;system_date&gt;SYSDATE()&lt;/system_date&gt;
	&lt;rowset&gt;SYSDATE()&lt;/rowset&gt;
	&lt;selectcomment&gt;SELECT COMMENTS FROM USER_COL_COMMENTS WHERE TABLE_NAME='$TABLE' AND COLUMN_NAME='$COLUMN'&lt;/selectcomment&gt;
	&lt;updatecomment type="sql"&gt;COMMENT ON COLUMN $TABLE.$COLUMN IS '$COMMENT'&lt;/updatecomment&gt;
	&lt;updatecomment type="create"&gt;COMMENT ON COLUMN $TABLE.$COLUMN IS '$COMMENT'&lt;/updatecomment&gt;
&lt;/db&gt;
</pre>
*/
public class ConnectInfo implements Cloneable
{
	public static final int	COMMENT_NONE	= 0;
	public static final int	COMMENT_UPDATE	= 1;
	public static final int	COMMENT_CREATE	= 2;

	public ConnectInfo() {
		properties = new Properties();
	}

	public ConnectInfo( IConfiguration config ) throws Exception {
		properties = new Properties();
		IConfiguration c;
		IConfiguration attr = config.getAttributes();
		name = attr.get( "name" );
		jar = config.get( "jar", null );
		driver = config.get( "driver" );
		url = config.get( "url" );
		user = config.get( "user", null );
		password = config.get( "password", null );
		encode = config.get( "encode", null );
		Iterator<IConfiguration> itr = config.getChilds( "properties" );
		while ( itr.hasNext()) {
			c = (IConfiguration )itr.next();
			attr = c.getAttributes();
			properties.put( attr.get( "key" ), attr.get( "value" ));
		}

		catalog = config.get( "catalog", null );
		schema = config.get( "schema", null );
		systemDate = config.get( "system_date", null );
		rowSet = config.get( "rowset", null );

		updateType = COMMENT_NONE;
		c = config.getChild( "updatecomment" );
		if ( c != null ) {
			String var = c.getAttributes().get( "type", "" );
			if ( var.equals( "update" )) {
				updateType = COMMENT_UPDATE;
			} else
			if ( var.equals( "create" )) {
				updateType = COMMENT_CREATE;
			}
			updateComment = c.get();
		}
		c = config.getChild( "selectcomment" );
		if ( c != null ) {
			selectComment = c.get();
		}
	}

	/**
	* 設定情報を保存します。
	* @param    config  設定情報
	*/
	public void saveConfig( IConfiguration config ) throws Exception {
		config.setAttribute( "name", name );
		if ( jar != null && jar.length() > 0 ) {
			config.addChild( "jar" ).set( jar );
		}
		config.addChild( "driver" ).set( driver );
		config.addChild( "url" ).set( url );
		if ( user != null && user.length() > 0 ) {
			config.addChild( "user" ).set( user );
		}
		if ( password != null && password.length() > 0 ) {
			config.addChild( "password" ).set( password );
		}
		if ( encode != null && encode.length() > 0 ) {
			config.addChild( "encode" ).set( encode );
		}
		Iterator itr = properties.keySet().iterator();
		while ( itr.hasNext()) {
			String key = (String )itr.next();
			String value = (String )properties.get( key );
			IConfiguration c = config.addChild( "properties" );
			c.setAttribute( "key", key );
			c.setAttribute( "value", value );
		}
		if ( catalog != null && catalog.length() > 0 ) {
			config.addChild( "catalog" ).set( catalog );
		}
		if ( schema != null && schema.length() > 0 ) {
			config.addChild( "schema" ).set( schema );
		}
		if ( systemDate != null && systemDate.length() > 0 ) {
			config.addChild( "system_date" ).set( systemDate );
		}
		if ( rowSet != null && rowSet.length() > 0 ) {
			config.addChild( "rowset" ).set( rowSet );
		}
		if ( updateType != COMMENT_NONE ) {
			IConfiguration c = config.addChild( "comment" );
			switch ( updateType ) {
			case COMMENT_UPDATE: c.setAttribute( "type", "update" ); break;
			case COMMENT_CREATE: c.setAttribute( "type", "create" ); break;
			}
			c.set( updateComment );
		}
	}

	public Object clone() throws CloneNotSupportedException {
		ConnectInfo ret = (ConnectInfo )super.clone();
		return ret;
	}

	String	name;	// 名称
	String	jar;	// Jar
	String	driver;	// Driver
	String	url;	// URL
	String	user;	// ユーザ
	String	password;	// パスワード
	String	encode;	// Encode
	Properties	properties;	// 接続プロパティ
	String	catalog;	// DBのCatalog
	String	schema;	// DBのSchema
	String	displayName;	// 表示名称
	String	systemDate;	// 現在時刻関数
	String	rowSet;	// rowsetクラス
	int	updateType;	// COMMENT更新用SQL種別
	String	updateComment;	// COMMENT更新用SQL
	String	selectComment;	// COMMENT取得用SQL
	DbInfo	dbInfo;	// DB接続情報
	Driver	sqlDriver;	// DBドライバ

	/**
	* 名称を設定します。
	* @param	var		設定するデータ
	*/
	public void setName( String var ) {
		this.name = var;
	}
	/**
	* 名称を取得します。
	* @return	名称
	*/
	public String getName() {
		return name;
	}

	/**
	* Jarを設定します。
	* @param	var		設定するデータ
	*/
	public void setJar( String var ) {
		this.jar = var;
	}
	/**
	* Jarを取得します。
	* @return	Jar
	*/
	public String getJar() {
		return jar;
	}

	/**
	* Driverを設定します。
	* @param	var		設定するデータ
	*/
	public void setDriver( String var ) {
		this.driver = var;
	}
	/**
	* Driverを取得します。
	* @return	Driver
	*/
	public String getDriver() {
		return driver;
	}

	/**
	* URLを設定します。
	* @param	var		設定するデータ
	*/
	public void setUrl( String var ) {
		this.url = var;
	}
	/**
	* URLを取得します。
	* @return	URL
	*/
	public String getUrl() {
		return url;
	}

	/**
	* ユーザを設定します。
	* @param	var		設定するデータ
	*/
	public void setUser( String var ) {
		this.user = var;
	}
	/**
	* ユーザを取得します。
	* @return	ユーザ
	*/
	public String getUser() {
		return user;
	}

	/**
	* パスワードを設定します。
	* @param	var		設定するデータ
	*/
	public void setPassword( String var ) {
		this.password = var;
	}
	/**
	* パスワードを取得します。
	* @return	パスワード
	*/
	public String getPassword() {
		return password;
	}

	/**
	* Encodeを設定します。
	* @param	var		設定するデータ
	*/
	public void setEncode( String var ) {
		this.encode = var;
	}
	/**
	* Encodeを取得します。
	* @return	Encode
	*/
	public String getEncode() {
		return encode;
	}

	/**
	* 接続プロパティを設定します。
	* @param	var		設定するデータ
	*/
	public void setProperties( Properties var ) {
		this.properties = var;
	}
	/**
	* 接続プロパティを取得します。
	* @return	接続プロパティ
	*/
	public Properties getProperties() {
		return properties;
	}

	/**
	* DBのCatalogを設定します。
	* @param	var		設定するデータ
	*/
	public void setCatalog( String var ) {
		this.catalog = var;
	}
	/**
	* DBのCatalogを取得します。
	* @return	DBのCatalog
	*/
	public String getCatalog() {
		return catalog;
	}

	/**
	* DBのSchemaを設定します。
	* @param	var		設定するデータ
	*/
	public void setSchema( String var ) {
		this.schema = var;
	}
	/**
	* DBのSchemaを取得します。
	* @return	DBのSchema
	*/
	public String getSchema() {
		return schema;
	}

	/**
	* 表示名称を設定します。
	* @param	var		設定するデータ
	*/
	public void setDisplayName( String var ) {
		this.displayName = var;
	}
	/**
	* 表示名称を取得します。
	* @return	表示名称
	*/
	public String getDisplayName() {
		return displayName;
	}

	/**
	* 現在時刻関数を設定します。
	* @param	var		設定するデータ
	*/
	public void setSystemDate( String var ) {
		this.systemDate = var;
	}
	/**
	* 現在時刻関数を取得します。
	* @return	現在時刻関数
	*/
	public String getSystemDate() {
		return systemDate;
	}

	/**
	* rowsetクラスを設定します。
	* @param	var		設定するデータ
	*/
	public void setRowSet( String var ) {
		this.rowSet = var;
	}
	/**
	* rowsetクラスを取得します。
	* @return	rowsetクラス
	*/
	public String getRowSet() {
		return rowSet;
	}

	/**
	* COMMENT更新用SQL種別を設定します。
	* @param	var		設定するデータ
	*/
	public void setUpdateType( int var ) {
		this.updateType = var;
	}
	/**
	* COMMENT更新用SQL種別を取得します。
	* @return	COMMENT更新用SQL種別
	*/
	public int getUpdateType() {
		return updateType;
	}

	/**
	* COMMENT更新用SQLを設定します。
	* @param	var		設定するデータ
	*/
	public void setUpdateComment( String var ) {
		this.updateComment = var;
	}
	/**
	* COMMENT更新用SQLを取得します。
	* @return	COMMENT更新用SQL
	*/
	public String getUpdateComment() {
		return updateComment;
	}

	/**
	* COMMENT取得用SQLを設定します。
	* @param	var		設定するデータ
	*/
	public void setSelectComment( String var ) {
		this.selectComment = var;
	}
	/**
	* COMMENT取得用SQLを取得します。
	* @return	COMMENT取得用SQL
	*/
	public String getSelectComment() {
		return selectComment;
	}

	/**
	* DB接続情報を設定します。
	* @param	var		設定するデータ
	*/
	public void setDbInfo( DbInfo var ) {
		this.dbInfo = var;
	}
	/**
	* DB接続情報を取得します。
	* @return	DB接続情報
	*/
	public DbInfo getDbInfo() {
		return dbInfo;
	}

	/**
	* DBドライバを設定します。
	* @param	var		設定するデータ
	*/
	public void setSqlDriver( Driver var ) {
		this.sqlDriver = var;
	}
	/**
	* DBドライバを取得します。
	* @return	DBドライバ
	*/
	public Driver getSqlDriver() {
		return sqlDriver;
	}

}
